pub(crate) struct SyntaxFixups {
pub(crate) append: FxHashMap<SyntaxElement, Vec<Leaf>>,
pub(crate) remove: FxHashSet<SyntaxElement>,
pub(crate) undo_info: SyntaxFixupUndoInfo,
}Expand description
The result of calculating fixes for a syntax node – a bunch of changes (appending to and replacing nodes), the information that is needed to reverse those changes afterwards, and a token map.
Fields
append: FxHashMap<SyntaxElement, Vec<Leaf>>remove: FxHashSet<SyntaxElement>undo_info: SyntaxFixupUndoInfoTrait Implementations
Sourceimpl Debug for SyntaxFixups
impl Debug for SyntaxFixups
Sourceimpl Default for SyntaxFixups
impl Default for SyntaxFixups
Sourcefn default() -> SyntaxFixups
fn default() -> SyntaxFixups
Returns the “default value” for a type. Read more